@@ -1,4 +1,3 @@
-static const char rcsid[]="$Id: compose.c,v 2.1 1998/12/16 11:10:23 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -568,9 +567,9 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
 	  s  = b->filename;  par = b->parameter;
 	  b->filename  = NULL;  b->parameter = NULL;
 	  
-	  mutt_parse_content_type(buf, b);
+	  mutt_parse_content_type (buf, b);
 
-	  safe_free((void **) &b->filename);
+	  safe_free ((void **) &b->filename);
 	  b->filename = s;
 	  
 	  if ((s = mutt_get_parameter("charset", b->parameter)))
@@ -589,6 +588,15 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
 	  mutt_free_parameter(&b->parameter);
 	  b->parameter = par;
 
+	  /* this may have been a "structured" message */
+	  if  (b->parts)
+	    mutt_free_body (&b->parts);
+	  if (b->hdr)
+	  {
+	    b->hdr->content = NULL;
+	    mutt_free_header (&b->hdr);
+	  }
+	  
 	  menu->redraw = REDRAW_CURRENT;
 	}
 	break;
@@ -643,6 +651,8 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
       case OP_COMPOSE_TOGGLE_UNLINK:
 	CHECK_COUNT;
 	idx[menu->current]->content->unlink = !idx[menu->current]->content->unlink;
+	if (option (OPTRESOLVE) && menu->current + 1 < menu->max)
+	  menu->current++;
 	menu->redraw = REDRAW_INDEX;
 	break;
 
