@@ -1,4 +1,3 @@
-static const char rcsid[]="$Id: copy.c,v 2.0 1998/12/12 08:05:59 roessler Rel $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -494,6 +493,8 @@ _mutt_copy_message (FILE *fpout, FILE *fpin, HEADER *hdr, BODY *body,
       s.prefix = prefix;
     if (flags & M_CM_DISPLAY)
       s.flags |= M_DISPLAY;
+    if (flags & M_CM_WEED)
+      s.flags |= M_WEED;
 
 
     mutt_body_handler (body, &s);
@@ -561,7 +562,8 @@ _mutt_append_message (CONTEXT *dest, FILE *fpin, CONTEXT *src, HEADER *hdr,
     chflags |= CH_FROM;
   chflags |= (dest->magic == M_MAILDIR ? CH_NOSTATUS : CH_UPDATE);
   r = _mutt_copy_message (msg->fp, fpin, hdr, body, flags, chflags);
-  mx_close_message (&msg);
+  if (mx_close_message (&msg) != 0)
+    return (-1);
   return r;
 }
 
