@@ -1,4 +1,3 @@
-static const char rcsid[]="$Id: main.c,v 2.1 1998/12/30 07:58:38 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -192,10 +191,10 @@ static void show_version (void)
 	"-HAVE_REGCOMP  "
 #endif
 
-#ifdef USE_GNU_RX
-	"+USE_GNU_RX  "
+#ifdef USE_GNU_REGEX
+	"+USE_GNU_REGEX  "
 #else
-	"-USE_GNU_RX  "
+	"-USE_GNU_REGEX  "
 #endif
 
 #ifdef HAVE_COLOR
